@@ -9,6 +9,7 @@ from ._guardpoint_cards import CardsAPI
 from ._guardpoint_cardholders import CardholdersAPI
 from .guardpoint_error import GuardPointError
 from ._guardpoint_areas import AreasAPI
+from .guardpoint_utils import url_parser
 
 log = logging.getLogger(__name__)
 
@@ -19,13 +20,19 @@ class GuardPoint(GuardPointConnection, CardsAPI, CardholdersAPI, AreasAPI, Secur
     def __init__(self, **kwargs):
         # Set default values if not present
         host = kwargs.get('host', "localhost")
-        port = kwargs.get('port', 10695)
+        port = kwargs.get('port', None)
+        url_components = url_parser(host)
+        if url_components['host'] == '':
+            url_components['host'] = url_components['path']
+            url_components['path'] = ''
+        if port:
+            url_components['port'] = port
         auth = kwargs.get('auth', GuardPointAuthType.BEARER_TOKEN)
         user = kwargs.get('username', "admin")
         pwd = kwargs.get('pwd', "admin")
         key = kwargs.get('key', "00000000-0000-0000-0000-000000000000")
         token = kwargs.get('token', None)
-        super().__init__(host=host, port=port, auth=auth, user=user, pwd=pwd, key=key, token=token)
+        super().__init__(url_components=url_components, auth=auth, user=user, pwd=pwd, key=key, token=token)
 
 
 
